==> cert_creation-1.7.8-sources.jar: com/xdja/safeclient/certcreation/service/CommonService.java <==
package com.xdja.safeclient.certcreation.service;

import android.content.Context;

import com.xdja.safeclient.certcreation.HttpResponseCallBack;
import com.xdja.safeclient.certcreation.bean.response.BaseErrorResponse;
import com.xdja.safeclient.certcreation.bean.response.CommonResponse;
import com.xdja.safeclient.certcreation.device.NetVHSMHandle;
import com.xdja.safeclient.certcreation.util.SharePreferencesUtil;

import java.io.IOException;

import okhttp3.Call;

/**
 * 多个业务共用的接口
 * Created by jff on 2019/7/18.
 */

public class CommonService {
    public static void getVhsmServerURL(final Context context) {

        new CertService().getVhsmURL(NetVHSMHandle.getNetVhsmCardId(), new HttpResponseCallBack<CommonResponse>() {
            @Override
            public void onOtherException(Exception e) {

            }

            @Override
            public void onIoExceptionFailure(Call call, IOException e) {

            }

            @Override
            public void onSuccessfulResponse(Call call, CommonResponse commonResponse) {
                if (commonResponse.getResult().equals("0")) {
                    String initIP = commonResponse.getMessage();
                    if (initIP != null && initIP.length() > 0) {
                        SharePreferencesUtil.saveVHSMUrl(context, initIP);
                    }

                }
            }

            @Override
            public void onFailResponse(Call call, BaseErrorResponse baseErrorResponse) {

            }

            @Override
            public void dismissDialog() {

            }
        });
    }
}

==> cert_creation-1.8.1_3-sources.jar: com/xdja/safeclient/certcreation/service/CommonService.java <==
package com.xdja.safeclient.certcreation.service;

import android.content.Context;

import com.xdja.safeclient.certcreation.HttpResponseCallBack;
import com.xdja.safeclient.certcreation.bean.response.BaseErrorResponse;
import com.xdja.safeclient.certcreation.bean.response.CommonResponse;
import com.xdja.safeclient.certcreation.device.NetVHSMHandle;
import com.xdja.safeclient.certcreation.util.SharePreferencesUtil;

import java.io.IOException;

import okhttp3.Call;

/**
 * 多个业务共用的接口
 * Created by jff on 2019/7/18.
 */

public class CommonService {
    public static void getVhsmServerURL(final Context context) {

        new CertService().getVhsmURL(NetVHSMHandle.getNetVhsmCardId(context), new HttpResponseCallBack<CommonResponse>() {
            @Override
            public void onOtherException(Exception e) {

            }

            @Override
            public void onIoExceptionFailure(Call call, IOException e) {

            }

            @Override
            public void onSuccessfulResponse(Call call, CommonResponse commonResponse) {
                if (commonResponse.getResult().equals("0")) {
                    String initIP = commonResponse.getMessage();
                    if (initIP != null && initIP.length() > 0) {
                        SharePreferencesUtil.saveVHSMUrl(context, initIP);
                    }

                }
            }

            @Override
            public void onFailResponse(Call call, BaseErrorResponse baseErrorResponse) {

            }

            @Override
            public void dismissDialog() {

            }
        });
    }
}
